@@ -6,26 +6,38 @@ import (
 	"talisman/checksumcalculator"
 	"talisman/gitrepo"
 	"talisman/utility"
+
+	"github.com/sirupsen/logrus"
 )
 
 type ChecksumCmd struct {
 	fileNamePatterns []string
+	hasher           utility.SHA256Hasher
+	repoRoot         string
 }
 
 func NewChecksumCmd(fileNamePatterns []string) *ChecksumCmd {
-	return &ChecksumCmd{fileNamePatterns: fileNamePatterns}
+	wd, _ := os.Getwd()
+	hasher := utility.MakeHasher("checksum", wd)
+	return &ChecksumCmd{fileNamePatterns: fileNamePatterns, hasher: hasher, repoRoot: wd}
 }
 
 func (s *ChecksumCmd) Run() int {
-	wd, _ := os.Getwd()
-	repo := gitrepo.RepoLocatedAt(wd)
+	repo := gitrepo.RepoLocatedAt(s.repoRoot)
+	if s.hasher == nil {
+		logrus.Errorf("unable to start hasher")
+		return EXIT_FAILURE
+	}
+
 	gitTrackedFilesAsAdditions := repo.TrackedFilesAsAdditions()
 	gitTrackedFilesAsAdditions = append(gitTrackedFilesAsAdditions, repo.StagedAdditions()...)
-	cc := checksumcalculator.NewChecksumCalculator(utility.DefaultSHA256Hasher{}, gitTrackedFilesAsAdditions)
+
+	cc := checksumcalculator.NewChecksumCalculator(s.hasher, gitTrackedFilesAsAdditions)
 	rcSuggestion := cc.SuggestTalismanRC(s.fileNamePatterns)
+
 	if rcSuggestion != "" {
 		fmt.Print(rcSuggestion)
-		return 0
+		return EXIT_SUCCESS
 	}
-	return 1
+	return EXIT_FAILURE
 }
