@@ -2,6 +2,7 @@ package main
 
 import (
 	"fmt"
+	"os"
 	"talisman/detector"
 	"talisman/detector/helpers"
 	"talisman/gitrepo"
@@ -13,6 +14,10 @@ import (
 	logr "github.com/sirupsen/logrus"
 )
 
+const (
+	SCAN_MODE = "scan"
+)
+
 type ScannerCmd struct {
 	additions       []gitrepo.Addition
 	results         *helpers.DetectionResults
@@ -22,12 +27,13 @@ type ScannerCmd struct {
 //Run scans git commit history for potential secrets and returns 0 or 1 as exit code
 func (s *ScannerCmd) Run(tRC *talismanrc.TalismanRC) int {
 	fmt.Printf("\n\n")
-	utility.CreateArt("Running ScanMode..")
-	detector.DefaultChain(tRC).Test(s.additions, tRC, s.results)
+	utility.CreateArt("Running Scan..")
+	additionsToScan := tRC.FilterAdditions(s.additions)
+	detector.DefaultChain(tRC, "default").Test(additionsToScan, tRC, s.results)
 	reportsPath, err := report.GenerateReport(s.results, s.reportDirectory)
 	if err != nil {
 		logr.Errorf("error while generating report: %v", err)
-		return CompletedWithErrors
+		return EXIT_FAILURE
 	}
 
 	fmt.Printf("\nPlease check '%s' folder for the talisman scan report\n\n", reportsPath)
@@ -36,14 +42,16 @@ func (s *ScannerCmd) Run(tRC *talismanrc.TalismanRC) int {
 
 func (s *ScannerCmd) exitStatus() int {
 	if s.results.HasFailures() {
-		return CompletedWithErrors
+		return EXIT_FAILURE
 	}
-	return CompletedSuccessfully
+	return EXIT_SUCCESS
 }
 
 //NewScannerCmd Returns a new scanner command
 func NewScannerCmd(ignoreHistory bool, reportDirectory string) *ScannerCmd {
-	additions := scanner.GetAdditions(ignoreHistory)
+	repoRoot, _ := os.Getwd()
+	reader := gitrepo.NewBatchGitObjectHashReader(repoRoot)
+	additions := scanner.GetAdditions(ignoreHistory, reader)
 	return &ScannerCmd{
 		additions:       additions,
 		results:         helpers.NewDetectionResults(talismanrc.ScanMode),
