@@ -2,7 +2,7 @@ package filecontent
 
 import (
 	"bufio"
-	log "github.com/Sirupsen/logrus"
+	log "github.com/sirupsen/logrus"
 	"os"
 	"strings"
 )
