@@ -58,6 +58,55 @@ func TestResultsReportsFailures(t *testing.T) {
 	assert.Regexp(t, "Complete & utter failure", finalStringMessage, "Error report does not contain expected output")
 }
 
+func TestUpdateResultsSummary(t *testing.T) {
+	results := NewDetectionResults(talismanrc.HookMode)
+	categories := []string{"filecontent", "filename", "filesize"}
+
+	for _, category := range categories {
+		results.updateResultsSummary(category, false)
+	}
+	assert.Equal(t, 1, results.Summary.Types.Filename)
+	assert.Equal(t, 1, results.Summary.Types.Filecontent)
+	assert.Equal(t, 1, results.Summary.Types.Filesize)
+
+	for _, category := range categories {
+		results.updateResultsSummary(category, true)
+	}
+	assert.Equal(t, 0, results.Summary.Types.Filename)
+	assert.Equal(t, 0, results.Summary.Types.Filecontent)
+	assert.Equal(t, 0, results.Summary.Types.Filesize)
+}
+
+func TestErrorExitCodeInInteractive(t *testing.T) {
+	ctrl := gomock.NewController(t)
+	defer ctrl.Finish()
+
+	prompter := mock.NewMockPrompt(ctrl)
+	results := NewDetectionResults(talismanrc.HookMode)
+
+	promptContext := prompt.NewPromptContext(true, prompter)
+	prompter.EXPECT().Confirm(gomock.Any()).Return(false).Times(2)
+	results.Fail("some_file.pem", "filecontent", "Bomb", []string{}, severity.Low)
+	results.Fail("another.pem", "filecontent", "password", []string{}, severity.Low)
+	results.Report(promptContext, "default")
+	assert.True(t, results.HasFailures())
+}
+
+func TestSuccessExitCodeInInteractive(t *testing.T) {
+	ctrl := gomock.NewController(t)
+	defer ctrl.Finish()
+
+	prompter := mock.NewMockPrompt(ctrl)
+	results := NewDetectionResults(talismanrc.HookMode)
+
+	promptContext := prompt.NewPromptContext(true, prompter)
+	prompter.EXPECT().Confirm(gomock.Any()).Return(true).Times(2)
+	results.Fail("some_file.pem", "filecontent", "Bomb", []string{}, severity.Low)
+	results.Fail("another.pem", "filecontent", "password", []string{}, severity.Low)
+	results.Report(promptContext, "default")
+	assert.False(t, results.HasFailures())
+}
+
 // Presently not showing the ignored files in the log
 // func TestLoggingIgnoredFilesDoesNotCauseFailure(t *testing.T) {
 // 	results := NewDetectionResults(talismanrc.HookMode)
@@ -103,7 +152,7 @@ func TestTalismanRCSuggestionWhenThereAreFailures(t *testing.T) {
 		promptContext := prompt.NewPromptContext(true, prompter)
 		prompter.EXPECT().Confirm(gomock.Any()).Return(false).Times(0)
 
-		results.Report(promptContext)
+		results.Report(promptContext, "default")
 		bytesFromFile, err := afero.ReadFile(fs, ignoreFile)
 
 		assert.NoError(t, err)
@@ -116,7 +165,7 @@ func TestTalismanRCSuggestionWhenThereAreFailures(t *testing.T) {
 		prompter.EXPECT().Confirm("Do you want to add some_file.pem with above checksum in talismanrc ?").Return(false)
 		results.Fail("some_file.pem", "filecontent", "Bomb", []string{}, severity.Low)
 
-		results.Report(promptContext)
+		results.Report(promptContext, "default")
 		bytesFromFile, err := afero.ReadFile(fs, ignoreFile)
 
 		assert.NoError(t, err)
@@ -129,7 +178,7 @@ func TestTalismanRCSuggestionWhenThereAreFailures(t *testing.T) {
 		prompter.EXPECT().Confirm(gomock.Any()).Return(false).Times(0)
 		results.Fail("some_file.pem", "filecontent", "Bomb", []string{}, severity.Low)
 
-		results.Report(promptContext)
+		results.Report(promptContext, "default")
 		bytesFromFile, err := afero.ReadFile(fs, ignoreFile)
 
 		assert.NoError(t, err)
@@ -148,7 +197,7 @@ func TestTalismanRCSuggestionWhenThereAreFailures(t *testing.T) {
   checksum: 87139cc4d975333b25b6275f97680604add51b84eb8f4a3b9dcbbc652e6f27ac
 version: "1.0"
 `
-		results.Report(promptContext)
+		results.Report(promptContext, "default")
 		bytesFromFile, err := afero.ReadFile(fs, ignoreFile)
 
 		assert.NoError(t, err)
@@ -167,7 +216,7 @@ version: "1.0"
   checksum: 5bc0b0692a316bb2919263addaef0ffba3a21b9e1cca62a1028390e97e861e4e
 version: "1.0"
 `
-		results.Report(promptContext)
+		results.Report(promptContext, "default")
 		bytesFromFile, err := afero.ReadFile(fs, ignoreFile)
 
 		assert.NoError(t, err)
@@ -190,7 +239,7 @@ version: "1.0"
   checksum: 87139cc4d975333b25b6275f97680604add51b84eb8f4a3b9dcbbc652e6f27ac
 version: "1.0"
 `
-		results.Report(promptContext)
+		results.Report(promptContext, "default")
 		bytesFromFile, err := afero.ReadFile(fs, ignoreFile)
 
 		assert.NoError(t, err)
