@@ -2,14 +2,14 @@ package gitrepo
 
 import (
 	"fmt"
-	log "github.com/sirupsen/logrus"
 	"os"
 	"os/exec"
 	"path"
 	"path/filepath"
 	"regexp"
 	"strings"
-	"talisman/utility"
+
+	log "github.com/sirupsen/logrus"
 )
 
 //FilePath represents the absolute path of an added file
@@ -103,8 +103,8 @@ func (repo GitRepo) GetDiffForStagedFiles() []Addition {
 
 func MatchGitDiffLine(gitDiffString string) (bool, string) {
 	if strings.Contains(gitDiffString, "diff --git") {
-		fileNameLength := (len(gitDiffString) - len("diff --git a/ b/"))/2
-		regexPattern := fmt.Sprintf("^diff --git a/(.{%v}) b/(.{%v})$", fileNameLength, fileNameLength);
+		fileNameLength := (len(gitDiffString) - len("diff --git a/ b/")) / 2
+		regexPattern := fmt.Sprintf("^diff --git a/(.{%v}) b/(.{%v})$", fileNameLength, fileNameLength)
 		headerRegex := regexp.MustCompile(regexPattern)
 
 		if headerRegex.MatchString(gitDiffString) {
@@ -122,7 +122,7 @@ func (repo GitRepo) StagedAdditions() []Addition {
 	files := repo.stagedFiles()
 	result := make([]Addition, len(files))
 	for i, file := range files {
-		data := repo.stagedVersionOfFile(file)
+		data, _ := repo.readRepoFile(file, GIT_STAGED_PREFIX)
 		result[i] = NewAddition(file, data)
 	}
 
@@ -146,7 +146,7 @@ func (repo GitRepo) AdditionsWithinRange(oldCommit string, newCommit string) []A
 	files := repo.outgoingNonDeletedFiles(oldCommit, newCommit)
 	result := make([]Addition, len(files))
 	for i, file := range files {
-		data, _ := repo.ReadRepoFile(file)
+		data, _ := repo.readRepoFile(file, GIT_HEAD_PREFIX)
 		result[i] = NewAddition(file, data)
 	}
 	log.WithFields(log.Fields{
@@ -176,23 +176,6 @@ func NewScannerAddition(filePath string, commits []string, content []byte) Addit
 	}
 }
 
-//ReadRepoFile returns the contents of the supplied relative filename by locating it in the git repo
-func (repo GitRepo) ReadRepoFile(fileName string) ([]byte, error) {
-	path := filepath.Join(repo.root, fileName)
-	log.Debugf("reading file %s", path)
-	return utility.SafeReadFile(path)
-}
-
-//ReadRepoFileOrNothing returns the contents of the supplied relative filename by locating it in the git repo.
-//If the given file cannot be located in the repo, then an empty array of bytes is returned for the content.
-func (repo GitRepo) ReadRepoFileOrNothing(fileName string) ([]byte, error) {
-	filepath := path.Join(repo.root, fileName)
-	if _, err := os.Stat(filepath); err == nil {
-		return repo.ReadRepoFile(fileName)
-	}
-	return make([]byte, 0), nil
-}
-
 //CheckIfFileExists checks if the file exists on the file system. Does not look into the file contents
 //Returns TRUE if file exists
 //Returns FALSE if the file is not found
@@ -271,14 +254,7 @@ func (repo GitRepo) currentBranch() string {
 
 func (repo GitRepo) hasBranch() bool {
 	byteArray := repo.executeRepoCommand("git", "branch")
-	if len(string(byteArray)) != 0 {
-		return true
-	}
-	return false
-}
-
-func (repo GitRepo) stagedVersionOfFile(file string) []byte {
-	return repo.executeRepoCommand("git", "show", ":"+file)
+	return len(string(byteArray)) != 0
 }
 
 func (repo GitRepo) outgoingNonDeletedFiles(oldCommit, newCommit string) []string {
@@ -321,9 +297,7 @@ func (repo GitRepo) executeRepoCommand(commandName string, args ...string) []byt
 		"command": commandName,
 		"args":    args,
 	}).Debug("Building repo command")
-	result := exec.Command(commandName, args...)
-	result.Dir = repo.root
-	co, err := result.CombinedOutput()
+	co, err := repo.rawExecuteRepoCommand(commandName, args...)
 	logEntry := log.WithFields(log.Fields{
 		"dir":     repo.root,
 		"command": fmt.Sprintf("%s %s", commandName, strings.Join(args, " ")),
@@ -331,9 +305,26 @@ func (repo GitRepo) executeRepoCommand(commandName string, args ...string) []byt
 		"error":   err,
 	})
 	if err == nil {
-		logEntry.Debug("Git command excuted successfully")
+		logEntry.Debug("Git command executed successfully")
 	} else {
 		logEntry.Fatal("Git command execution failed")
 	}
 	return co
 }
+
+func (repo GitRepo) rawExecuteRepoCommand(commandName string, args ...string) ([]byte, error) {
+	return repo.makeRepoCommand(commandName, args...).CombinedOutput()
+}
+
+func (repo GitRepo) makeRepoCommand(commandName string, args ...string) *exec.Cmd {
+	command := exec.Command(commandName, args...)
+	command.Dir = repo.root
+	return command
+}
+
+func (repo GitRepo) readRepoFile(fileName, prefix string) ([]byte, error) {
+	path := filepath.Join(repo.root, fileName)
+	log.Debugf("reading file %s", path)
+	fileExpression := fmt.Sprintf("%s:%s", prefix, fileName)
+	return repo.rawExecuteRepoCommand("git", "cat-file", "-p", fileExpression)
+}
