@@ -1,6 +1,7 @@
 package talismanrc
 
 import (
+	"fmt"
 	"io/ioutil"
 	"os"
 	"testing"
@@ -60,35 +61,49 @@ func TestDirectoryPatterns(t *testing.T) {
 }
 
 func TestIgnoreAdditionsByScope(t *testing.T) {
-	file1 := testAddition("yarn.lock")
-	file2 := testAddition("similaryarn.lock")
-	file3 := testAddition("java.lock")
-	file4 := testAddition("Gopkg.lock")
-	file5 := testAddition("vendors/abc")
-	file6 := testAddition("imgJpeg.jpeg")
-	file7 := testAddition("imgJpg.jpg")
-	file8 := testAddition("imgPng.png")
-	additions := []gitrepo.Addition{file1, file2, file3, file4, file5, file6, file7, file8}
+	testTable := map[string][]gitrepo.Addition{
+		"node": {
+			testAddition("yarn.lock"),
+			testAddition("package-lock.json"),
+			testAddition("node_modules/module1/foo.js")},
+		"go": {
+			testAddition("Gopkg.lock"),
+			testAddition("makefile"),
+			testAddition("go.mod"), testAddition("go.sum"),
+			testAddition("Gopkg.toml"), testAddition("Gopkg.lock"),
+			testAddition("glide.yaml"), testAddition("glide.lock"),
+		},
+		"images": {
+			testAddition("img.jpeg"),
+			testAddition("img.jpg"),
+			testAddition("img.png"),
+			testAddition("img.tiff"),
+			testAddition("img.bmp"),
+		},
+		"bazel": {testAddition("bazelfile.bzl")},
+		"terraform": {
+			testAddition(".terraform.lock.hcl"),
+			testAddition("foo/.terraform.lock.hcl"),
+			testAddition("foo/bar/.terraform.lock.hcl"),
+		},
+		"php": {
+			testAddition("composer.lock"),
+		},
+		"python": {
+			testAddition("poetry.lock"),
+			testAddition("Pipfile.lock"),
+		},
+	}
 
-	scopesToIgnore := []string{"node", "go", "images"}
-	talismanRCConfig := createTalismanRCWithScopeIgnores(scopesToIgnore)
-
-	nodeIgnores := []string{"node.lock", "*yarn.lock"}
-	javaIgnores := []string{"java.lock"}
-	goIgnores := []string{"go.lock", "Gopkg.lock", "vendors/"}
-	imageIgnores := []string{"*.jpeg", "*.jpg", "*.png"}
-	scopesMap := map[string][]string{"node": nodeIgnores, "java": javaIgnores, "go": goIgnores, "images": imageIgnores}
-	knownScopes = scopesMap
-	filteredAdditions := talismanRCConfig.FilterAdditions(additions)
-
-	assert.NotContains(t, filteredAdditions, file1)
-	assert.NotContains(t, filteredAdditions, file2)
-	assert.Contains(t, filteredAdditions, file3)
-	assert.NotContains(t, filteredAdditions, file4)
-	assert.NotContains(t, filteredAdditions, file5)
-	assert.NotContains(t, filteredAdditions, file6)
-	assert.NotContains(t, filteredAdditions, file7)
-	assert.NotContains(t, filteredAdditions, file8)
+	for scopeName, additions := range testTable {
+		t.Run(fmt.Sprintf("should ignore files for %s scope", scopeName), func(t *testing.T) {
+			talismanRCConfig := createTalismanRCWithScopeIgnores([]string{scopeName})
+			filteredAdditions := talismanRCConfig.FilterAdditions(additions)
+			for _, addition := range additions {
+				assert.NotContains(t, filteredAdditions, addition, "Expected %s to be ignored", addition.Name)
+			}
+		})
+	}
 }
 
 func TestIgnoringDetectors(t *testing.T) {
@@ -104,12 +119,8 @@ func TestMakeWithFileIgnores(t *testing.T) {
 }
 
 func TestBuildIgnoreConfig(t *testing.T) {
-	var ignoreConfig IgnoreConfig
-	ignoreConfig = BuildIgnoreConfig(HookMode, "filename", "asdfasdfasdfasdfasdf", nil)
+	ignoreConfig := BuildIgnoreConfig(HookMode, "filename", "asdfasdfasdfasdfasdf", nil)
 	assert.IsType(t, &FileIgnoreConfig{}, ignoreConfig)
-
-	ignoreConfig = BuildIgnoreConfig(ScanMode, "filename", "asdfasdfasdfasdfasdf", nil)
-	assert.IsType(t, &ScanFileIgnoreConfig{}, ignoreConfig)
 }
 
 func TestAddIgnoreFilesInHookMode(t *testing.T) {
@@ -126,21 +137,6 @@ func TestAddIgnoreFilesInHookMode(t *testing.T) {
 	os.Remove(DefaultRCFileName)
 }
 
-func TestAddIgnoreFilesInScanMode(t *testing.T) {
-	ignoreConfig := &ScanFileIgnoreConfig{
-		FileName:        "Foo",
-		Checksums:       []string{"SomeCheckSum"},
-		IgnoreDetectors: []string{},
-		AllowedPatterns: []string{}}
-	os.Remove(DefaultRCFileName)
-	talismanRCConfig := createTalismanRCWithScopeIgnores([]string{})
-	talismanRCConfig.base.AddIgnores(ScanMode, []IgnoreConfig{ignoreConfig})
-	talismanRCScanConfigFromFile := ConfigFromFile()
-	assert.Equal(t, 1, len(talismanRCScanConfigFromFile.ScanConfig.FileIgnoreConfig))
-	assert.Equal(t, 0, len(talismanRCScanConfigFromFile.FileIgnoreConfig))
-	os.Remove(DefaultRCFileName)
-}
-
 func assertDenies(line, ignoreDetector string, path string, t *testing.T) {
 	assertDeniesDetector(line, ignoreDetector, path, "filename", t)
 }
@@ -213,57 +209,6 @@ func TestFileIgnoreConfig_GetAllowedPatterns(t *testing.T) {
 	assert.Regexp(t, allowedPatterns[0], "fileName")
 }
 
-func TestScanFileIgnoreConfig_ChecksumMatches(t *testing.T) {
-	fileIgnoreConfig := &ScanFileIgnoreConfig{
-		FileName:        "some_filename",
-		Checksums:       []string{"some_checksum", "some_other_checksum"},
-		IgnoreDetectors: nil,
-		AllowedPatterns: nil,
-	}
-
-	assert.True(t, fileIgnoreConfig.ChecksumMatches("some_checksum"))
-	assert.True(t, fileIgnoreConfig.ChecksumMatches("some_other_checksum"))
-	assert.False(t, fileIgnoreConfig.ChecksumMatches("some_different_checksum"))
-}
-
-func TestScanFileIgnoreConfig_isEffective(t *testing.T) {
-	fileIgnoreConfig := &ScanFileIgnoreConfig{
-		FileName:        "some_filename",
-		Checksums:       []string{"some_checksum", "some_other_checksum"},
-		IgnoreDetectors: nil,
-		AllowedPatterns: nil,
-	}
-	//Ignore config does not apply when detector not ignored
-	assert.False(t, fileIgnoreConfig.isEffective("filename"))
-
-	//Ignore config applies when detector explicitly ignored
-	fileIgnoreConfig.IgnoreDetectors = []string{"filename"}
-	assert.True(t, fileIgnoreConfig.isEffective("filename"))
-
-	//Ignore config does not apply when filename not set
-	fileIgnoreConfig.FileName = ""
-	assert.False(t, fileIgnoreConfig.isEffective("filename"))
-}
-
-func TestScanFileIgnoreConfig_GetAllowedPatterns(t *testing.T) {
-	fileIgnoreConfig := &ScanFileIgnoreConfig{
-		FileName:        "some_filename",
-		Checksums:       nil,
-		IgnoreDetectors: nil,
-		AllowedPatterns: nil,
-	}
-
-	//No allowed patterns specified
-	allowedPatterns := fileIgnoreConfig.GetAllowedPatterns()
-	assert.Equal(t, 0, len(allowedPatterns))
-
-	fileIgnoreConfig.compiledPatterns = nil
-	fileIgnoreConfig.AllowedPatterns = []string{"[Ff]ile[nN]ame"}
-	allowedPatterns = fileIgnoreConfig.GetAllowedPatterns()
-	assert.Equal(t, 1, len(allowedPatterns))
-	assert.Regexp(t, allowedPatterns[0], "fileName")
-}
-
 func TestSuggestRCFor(t *testing.T) {
 	t.Run("should suggest proper RC when ignore configs are valid", func(t *testing.T) {
 		fileIgnoreConfigs := []IgnoreConfig{
@@ -287,10 +232,6 @@ version: ""
 				FileName: "some_filename",
 				Checksum: "some_checksum",
 			},
-			&ScanFileIgnoreConfig{
-				FileName:  "some_other_filename",
-				Checksums: []string{"some_other_checksum"},
-			},
 		}
 		expectedRC := `fileignoreconfig:
 - filename: some_filename
@@ -325,4 +266,33 @@ func TestFor(t *testing.T) {
 		assert.True(t, rc.IgnoreConfigs[2].ChecksumMatches("file3_checksum"))
 
 	})
+
+
+}
+
+func TestForScan(t *testing.T) {
+	var repoFileReader = func(string) ([]byte, error) {
+		return []byte(`fileignoreconfig:
+- filename: testfile_1.yml
+  checksum: file1_checksum
+- filename: testfile_2.yml
+  checksum: file2_checksum
+- filename: testfile_3.yml
+  checksum: file3_checksum`), nil
+	}
+	t.Run("talismanrc.ForScan(ignoreHistory) should populate talismanrc for scan mode with ignore history", func(t *testing.T) {
+		setRepoFileReader(repoFileReader)
+		rc := ForScan(true)
+
+		assert.Equal(t, 3, len(rc.IgnoreConfigs))
+
+	})
+
+	t.Run("talismanrc.ForScan(ignoreHistory) should populate talismanrc for scan mode without ignore history", func(t *testing.T) {
+		setRepoFileReader(repoFileReader)
+		rc := ForScan(false)
+
+		assert.Equal(t, 0, len(rc.IgnoreConfigs))
+
+	})
 }
